@@ -64,7 +64,7 @@ panel_st_runtime <- function(data,
 #' @param expand_x expand size for scale_x_continuous padding
 #' @param expand_y expand size for scale_y_continuous padding
 #' @param selected_nodes select only some nodes in some plots
-#' @param labels labels: [ALL, 1CPU_per_NODE, 1GPU_per_NODE, FIRST_LAST]
+#' @param labels labels: [ALL, 1CPU_per_NODE, 1GPU_per_NODE, FIRST_LAST, NODES_only, NODES_1_in_10, 1CPU_1GPU, ALL_nompi]
 #' @param alpha alpha value for non-anomalous tasks
 #' @param idleness enable/disable idleness percentages in the plot
 #' @param taskdeps enable/disable task deps path highlighting
@@ -394,7 +394,6 @@ panel_st_agg_node <- function(data,
       filter(.data$Position >= 0)
   }
 
-  step <- 100
   df <- time_aggregation_prep(data$Application)
   df <- time_aggregation_do(df %>%
     group_by(.data$Node, .data$ResourceId, .data$ResourceType, .data$Task), step)
