@@ -5,7 +5,7 @@ test_that("starvz_plot works", {
   expect_equal(class(starvz_sample_lu), "starvz_data")
 
   pl <- starvz_plot(starvz_sample_lu)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   skip_on_cran()
   skip_if_not_installed("arrow")
@@ -15,37 +15,37 @@ test_that("starvz_plot works", {
   other_data$config <- starvz_read_config(system.file("extdata", "config.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data$config <- starvz_read_config(system.file("extdata", "agg.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data$config <- starvz_read_config(system.file("extdata", "selected.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data$config <- starvz_read_config(system.file("extdata", "imb.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data$config <- starvz_read_config(system.file("extdata", "agg_dynamic.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data$config <- starvz_read_config(system.file("extdata", "agg_static.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data$config <- starvz_read_config(system.file("extdata", "pmtool.yaml", package = "starvz"))
   pl <- NULL
   pl <- starvz_plot(other_data)
-  expect_equal(class(pl), c("patchwork", "gg", "ggplot"))
+  expect_true(is_ggplot(pl) && inherits(pl, "patchwork"))
 
   other_data <- starvz_phase1(system.file("extdata", "lu_trace", package = "starvz"), lu_colors, state_filter = 2, whichApplication = "lu")
   other_data <- starvz_read(system.file("extdata", "lu_trace", package = "starvz"), system.file("extdata", "config.yaml", package = "starvz"))
@@ -56,21 +56,21 @@ test_that("starvz_plot works", {
 
   pl <- NULL
   pl <- panel_handles(starvz_sample_lu, JobId = "0_1")
-  expect_equal(class(pl), c("gg", "ggplot"))
+  expect_true(is_ggplot(pl))
 
   pl <- NULL
   pl <- panel_memory_snap(starvz_sample_lu, 100, 10)
-  expect_equal(class(pl), c("gg", "ggplot"))
+  expect_true(is_ggplot(pl))
 
   pl <- NULL
   pl <- panel_memory_heatmap(starvz_sample_lu)
-  expect_equal(class(pl), c("gg", "ggplot"))
+  expect_true(is_ggplot(pl))
 
   pl <- NULL
   pl <- panel_dist2d(starvz_sample_lu)
-  expect_equal(class(pl), c("gg", "ggplot"))
+  expect_true(is_ggplot(pl))
 
   pl <- NULL
   pl <- panel_node_events(starvz_sample_lu)
-  expect_equal(class(pl), c("gg", "ggplot"))
+  expect_true(is_ggplot(pl))
 })
